@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1997/06/18 14:27:35 $
-# $Revision: 1.18.1.103 $
+# $Date: 1997/07/18 08:10:19 $
+# $Revision: 1.18.1.106 $
 #
 #
 package provide zircon 1.18
@@ -114,10 +114,12 @@ proc makeChannel {chan} {
     upvar #0 $this cdata CTO$net CTO
     catch {array set cdata \
       [uplevel #0 array get [getDefault defChan $net]] }
-    set cdata(name) $chan
-    set cdata(lname) $lchan
-    set cdata(keep) 0
-    set cdata(net) $net
+    array set cdata [list \
+	name	$chan \
+	lname	$lchan \
+	keep	0 \
+	net	$net \
+    ]
     $net register channels $this
     set CTO($lchan) $this
     return $this
@@ -169,7 +171,7 @@ proc channel_call {this op args} {
     upvar #0 $this cdata
     switch $op {
     isa { global OType ; switch $OType($this) [lindex $args 0] {return 1} ; return 0}
-    closetime { return [expr $cdata(closetime) / 1000]}
+    closetime { return [expr {$cdata(closetime) / 1000}]}
     active { switch {} $cdata(wid) {return 0} ; return 1 }
     type { global OType; return $OType($this); }
     }
@@ -193,7 +195,7 @@ proc channel_setTopic {this string} {
 proc channel_changeMode {this mode} {
     upvar #0 $this cdata
     set val $cdata($mode)
-    set cdata($mode) [expr !$val]
+    set cdata($mode) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]${mode}
 }
 #
@@ -364,6 +366,11 @@ proc channel_putJoin {this key} {
     array set cdata {p 0 m 0 s 0 i 0 t 0 n 0 a 0}
 }
 #
+proc channel_rejoin {this} {
+    $this optText KICKME "*** Attempting to rejoin"
+    $this putJoin {}
+}
+#
 proc channel_replace {this usr1 usr2} {
     if [$this active] {
 	$this optText NICK "*** [$usr1 name] is now known as [$usr2 name]"
@@ -1076,7 +1083,7 @@ proc pickOut {net win pos} {
 proc channel_getPrev {this} {
     upvar #0 $this cdata
     set rng [[$this text] tag range @me]
-    switch end $cdata(hpos) {set cdata(hpos) [expr [llength $rng] - 1]}
+    switch end $cdata(hpos) {set cdata(hpos) [expr {[llength $rng] - 1}]}
     switch {} [set foo [lindex $rng $cdata(hpos)]] {return {}}
     if {[incr cdata(hpos) -2] < 0}  {set cdata(hpos) end }
     return [pickOut [$this net] [$this text] $foo]
@@ -1085,7 +1092,7 @@ proc channel_getPrev {this} {
 proc channel_getNext {this} {
     upvar #0 $this cdata
     set rng [[$this text] tag range @me]
-    switch end $cdata(hpos) {set cdata(hpos) [expr [llength $rng] - 1]}
+    switch end $cdata(hpos) {set cdata(hpos) [expr {[llength $rng] - 1}]}
     if {[incr cdata(hpos) 2] >= [llength $rng]}  { set cdata(hpos) 1 }
     switch {} [set foo [lindex $rng $cdata(hpos)]] {return {}}
     return [pickOut [$this net] [$this text] $foo]
@@ -1099,7 +1106,7 @@ proc channel_flipActions {this} {
     bind $win <Return> $sret
     bind $win <$zircon(action)> $ret
     upvar #0 $this cdata
-    set cdata(actionmode) [expr !$cdata(actionmode)]
+    set cdata(actionmode) [expr {!$cdata(actionmode)}]
 }
 #
 # Leaving channels :
@@ -1432,7 +1439,7 @@ proc channel_userMode {this usr mode} {
     switch -exact -- $mode \
       o {set val [$this isOp $usr] ; set typ Op} \
       v {set val [$this isSpeaker $usr] ; set typ Spk}
-    set cdata($typ,$usr) [expr !$val]
+    set cdata($typ,$usr) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]$mode [$usr name]
 }
 #
