@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1997/06/18 14:27:39 $
-# $Revision: 1.18.1.38 $
+# $Date: 1997/07/18 08:01:25 $
+# $Revision: 1.18.1.39 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -107,7 +107,7 @@ class DChat {
     height	10	{int}
     width	80	{int}
 } {
-    caller	{}
+    caller	nil
     sock	{}
 }
 #
