@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1997/06/07 13:14:20 $
-# $Revision: 1.18.1.69 $
+# $Date: 1997/07/08 11:27:55 $
+# $Revision: 1.18.1.70 $
 #
 #
 package provide zircon 1.18
@@ -182,7 +182,7 @@ proc Control {this args} {
     set cdata(friends) [Friends frnd$net -control $this]
     if [$cdata(friends) menu] {
 	menubutton $ctl.friends -text Friends -menu $ctl.friends.menu
-	$cdata(friends) show
+	$cdata(friends) show -padx 4 -pady 5
     } {
 	button $ctl.friends -text Friends -command "$cdata(friends) show" 
 	if [$net showFriends] { $ctl.friends invoke }
@@ -442,7 +442,7 @@ proc control_serverFrame {this ctl} {
     set sm [tk_optionMenu $nf.server ${this}(server) {}]
     set srv [$this setupServer $net]
     set qm [buttonmenu $nf.quit -command "$this open" \
-      -text [trans open] -padx 5 -highlightthickness 0]
+      -text [trans open] -padx 5 -highlightthickness 0 -state disabled]
     menu $qm.menu -tearoff 0
     $qm.menu add command -label [trans new] -command "getQuit $this" 
     $qm.menu add separator
@@ -626,6 +626,18 @@ proc control_disableOpen {this} {
     [$this window].quit configure -state disabled
 }
 #
+proc control_enableOpen {this} {
+    [$this window].quit configure -state normal
+}
+#
+proc control_setOpen {this state} {
+    [$this window].quit configure -state $state
+}
+#
+proc control_openState {this} {
+    return [[$this window].quit cget -state]
+}
+#
 proc control_flagSet {this flg val} {
     if $val {
 	set cl red
