@@ -1,30 +1,30 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Ignore.tcl,v $
-# $Date: 1996/06/04 08:37:39 $
-# $Revision: 1.17.1.1 $
+# $Date: 1997/05/19 09:42:11 $
+# $Revision: 1.18.1.5 $
 #
+package provide zircon 1.18
 #
 proc ignore {pattern args} {
-    global current
+    global currentNet
     set pattern [string tolower $pattern]
     set lst [list $pattern $args]
-    set ignores [$current(net) ignores]
+    set ignores [$currentNet ignores]
     if {[set x [listmatch $ignores $pattern]] >= 0} {
 	listupdate ignores $x $lst
     } {
 	lappend ignores $lst
     }
-    $current(net) configure -ignores $ignores
+    $currentNet configure -ignores $ignores
 }
 #
 # Look and see if there are any ignores for this nick/name. List has format:
 #	{{pattern {list of what}} ......}
 #
 proc z_ignore {usr nm} {
-    set net [$usr net]
     set nm [string tolower $nm]
     set nk [$usr lname]
-    foreach ig [$net ignores] {
+    foreach ig [[$usr net] ignores] {
 	if [string match [lindex $ig 0] $nk!$nm] { return [lindex $ig 1] }
     }
     return {}
@@ -36,24 +36,21 @@ proc ignoreFlag {lst what} {
     set nk [lindex $lst 0]
     set v [lindex $lst 1]
     if {[set x [lsearch $v $what]] < 0} {
-	return [list ${nk} [lappend v $what]]
-    } {
-	return [list ${nk} [listdel v $x]]
+	return [list $nk [lappend v $what]]
     }
+    return [list $nk [listdel v $x]]
 }
 #
 proc flipIgnore {usr what} {
     set nk [$usr lname]
     set net [$usr net]
     set ignores [$net ignores]
-    if {[set x [listmatch $ignores ${nk}!*@*]] < 0} {
-	lappend ignores [ignoreFlag [list ${nk}!*@* {}] $what]
+    if {[set x [listmatch $ignores $nk!*@*]] < 0} {
+	lappend ignores [ignoreFlag [list $nk!*@* {}] $what]
     } {
 	listupdate ignores $x [ignoreFlag [lindex $ignores $x] $what]
     }
-    $net configure -ignores $ignores
-    global confChange
-    set confChange 1
+    $net configure -ignores $ignores -confChange 1
 }
 #
 proc ignoreAll {usr} {
@@ -70,18 +67,25 @@ proc ignoreAll {usr} {
 #
 proc ignoreClear {usr} {
     global zircon IFlag
-    set lst [z_ignore $usr *@*]
-    foreach x $zircon(ignore) {
-	set lx [string tolower $x]
-	if [ignoreSet $lst $lx] {
-	    flipIgnore $usr $lx
-	    set IFlag($usr,$lx) 0
+    foreach x $zircon(ignore) { set IFlag($usr,[string tolower $x]) 0}
+    set net [$usr net]
+    set nk [$usr name]
+    switch {} [set nm [$usr id]] { set nm *@* }
+    set lst [$net ignores]
+    set i 0
+    foreach ig [$net ignores] {
+	if [string match [lindex $ig 0] $nk!$nm] {
+	    listdel lst $i
+	    $net configure -ignores $lst -confChange 1
+	    break
 	}
+	incr i
     }
+    return {}
 }
 #
 proc addIgnoreMenu {win usr} {
-    if ![string compare $usr nil] return
+    switch nil $usr return
     $win add cascade -label Ignore -menu $win.ignore
     menu $win.ignore
     global zircon IFlag
@@ -95,3 +99,4 @@ proc addIgnoreMenu {win usr} {
 	set IFlag($usr,$lx) [ignoreSet $lst $lx]
     }
 }
+
