@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1997/06/18 14:27:50 $
-# $Revision: 1.18.1.102 $
+# $Date: 1997/07/18 08:01:29 $
+# $Revision: 1.18.1.104 $
 #
 package provide zircon 1.18
 #
@@ -257,6 +257,7 @@ proc net_startIRC {this srv args} {
     $this configure -ircop 0 -msgQueue {} -msgQTag {} -sysQueue {} \
       -hostid $srv -motdSeen 0
     set ctl [$this control]
+    set ost [$ctl openState]
     set ports [$srv port]
     switch {} $args {} default {
 	switch [set pt [lindex $args 0]] [lindex $ports 0] {} default {
@@ -287,6 +288,7 @@ proc net_startIRC {this srv args} {
 	    return $res
 	}
 	$ctl setQuit open "$ctl open"
+	$ctl setOpen $ost
 	retitleFrame .@ctl $this [$this name] 1
 	retitleFrame .@inf [$this info] [$this name] 1
     }
@@ -718,6 +720,7 @@ proc net_close {this args} {
     foreach x $ndata(splits) { $this cleanSplit $x }
     $this closeSock $qmsg
     $this flagControl disabled
+    $this configure -restricted 0
     foreach x {channels messages notices} {
 	foreach id $ndata($x) { $id flag disabled }
     }
@@ -735,7 +738,7 @@ proc net_close {this args} {
 	    after 0 $this doReconnect $srv
 	} {
 	    if [askUser SHUT [trans shutdown] "$msg\nReconnect?"] {
-	      after 0 $this doReconnect $srv
+		after 0 $this doReconnect $srv
 	    }
 	}
     }
