@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1997/06/18 14:28:02 $
-# $Revision: 1.18.1.45 $
+# $Date: 1997/07/08 11:28:04 $
+# $Revision: 1.18.1.46 $
 #
 package provide zircon 1.18
 #
@@ -350,7 +350,7 @@ proc deleteFrame {ctl net} {
 }
 #
 proc makeMB {win text} {
-    menubutton $win -text [trans $text] -menu $win.menu
+    menubutton $win -text [trans $text] -menu $win.menu -padx 4 -pady 5
     return [menu $win.menu]
 }
 #
