@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/bindings.tcl,v $
-# $Date: 1997/05/19 11:36:56 $
-# $Revision: 1.18.1.19 $
+# $Date: 1997/07/08 11:28:05 $
+# $Revision: 1.18.1.20 $
 #
 package provide zircon 1.18
 #
@@ -96,8 +96,8 @@ proc doInfoBindings {entry chid} {
 	bind $entry <Return> "notIdle %W $net ; $net doMisc2 $chid %W"
     }
 #
-    catch {bind $entry <KP_Next> "[$chid text] yview scroll 1 pages ; notIdle %W $net"}
-    catch {bind $entry <Next> [bind $entry <KP_Next>]}
-    catch {bind $entry <KP_Prior> "[$chid text] yview scroll -1 pages ; notIdle %W $net"}
-    catch {bind $entry <Prior> "[$chid text] yview scroll -1 pages ; notIdle %W $net"}
+    catch {bind $entry <KP_Next> "\[$chid text\] yview scroll 1 pages ; notIdle %W $net"}
+    catch {bind $entry <Next> "\[$chid text\] yview scroll 1 pages ; notIdle %W $net"}
+    catch {bind $entry <KP_Prior> "\[$chid text\] yview scroll -1 pages ; notIdle %W $net"}
+    catch {bind $entry <Prior> "\[$chid text\] yview scroll -1 pages ; notIdle %W $net"}
 }
