@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1997/06/09 12:03:00 $
-# $Revision: 1.18.1.60 $
+# $Date: 1997/07/18 08:02:15 $
+# $Revision: 1.18.1.61 $
 #
 package provide zircon 1.18
 #
@@ -52,7 +52,12 @@ proc getOValue {win opt lc uc} {
 }
 #
 proc getTValue {win win2 opt lc uc} {
-    switch {} [set x [option get ${win} $lc $uc]] {set x [$win2 cget -$opt]}
+    switch {} [set x [option get $win $lc $uc]] {
+	if [catch {$win2 cget -$opt} x] {
+	    error "Weird error!!!! ($x) - please tell \
+zircon@catless.ncl.ac.uk exactly what you were doing when this happened."
+	}
+    }
     return $x
 }
 #
