@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc.tcl,v $
-# $Date: 1997/06/18 14:28:13 $
-# $Revision: 1.18.1.33 $
+# $Date: 1997/07/08 11:28:07 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
@@ -207,10 +207,10 @@ proc irc302 {net prefix param pargs} {
 		text $w.text -yscrollcommand "$w.vscroller set"
 		grid $w.text -row 0 -column 0 -sticky nsew
 		grid $w.vscroller -row 0 -column 1 -sticky ns
-		grid [button $w.ok - -text Dismiss -command "
+		grid [button $w.ok -text [trans dismiss] -command "
 		    destroy $w
 		    catch {close $sock}
-		"] -
+		"]
 		puts $sock $user@$host
 	} {
 	    $net errmsg "Finger Error $uh : $sock"
