@@ -1,7 +1,9 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/upgrade.tcl,v $
-# $Date: 1996/06/04 08:37:39 $
-# $Revision: 1.17.1.1 $
+# $Date: 1997/04/02 11:34:05 $
+# $Revision: 1.18.1.3 $
+#
+package provide zircon 1.18
 #
 # Upgrade the rc file
 #
@@ -17,11 +19,11 @@ proc upgradeRC {} {
 proc upgrade2 {} {
     global zircon
     set x $zircon(prefdir)
-    if [catch {exec mkdir $x} msg] {
+    if [catch {filemkdir $x} msg] {
 	puts stderr "**** Could not make directory $x - $msg"
 	return
     }
-    if [catch {exec mv [glob ~]/.zirconrc $x/preferences} msg] {
+    if [catch {filerename  [file join ~ .zirconrc] [file join  $x preferences]} msg] {
 	puts stderr "**** Could not move .zirconrc to $x/preferences - $msg"
     }
 }
