@@ -1,13 +1,17 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/chat.tcl,v $
-# $Date: 1997/01/23 22:21:51 $
-# $Revision: 1.18.1.3 $
+# $Date: 1997/07/18 08:01:34 $
+# $Revision: 1.18.1.4 $
 #
 package provide Dcc 1.18
 #
 proc closeChat {cht who conn} {
     catch {fileevent $conn readable {} ; close $conn}
-    catch {uplevel #0 unset $conn}
+    upvar #0 $conn chdata
+    if [info exists chdata] {
+	$chdata(who) deref
+	unset chdata
+    }
     switch {} [info proc $cht] {} default {
 	$cht addText $who "*** $who has closed the connection"
     }
