@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1997/06/09 12:03:05 $
-# $Revision: 1.18.1.33 $
+# $Date: 1997/07/18 08:01:36 $
+# $Revision: 1.18.1.34 $
 #
 package provide Dcc 1.18
 #
@@ -28,6 +28,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	fconfigure $sok -translation {lf lf}
 	upvar #0 $sok chdata
 	set chdata(who) $usr
+	$usr ref
 	[set chdata(obj) \
 	    [set this [$net eval "Chat [list [$usr name]] -caller $usr"]]] show
 	$this addUser $chdata(who) 0 0
@@ -43,7 +44,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	    switch [tk_dialog .@dg$net {DCC Get} \
 	      "File \"$file\" already exists. Select the action you want to take." \
 	      warning 0 Overwrite Resume {Rename incoming} \
-	      {Rename Existing} Cancel] {
+	      {Rename Existing} Cancel] { 
 	    0 {}
 	    1 {
 		    $net CTCP DCC [$usr name] "RESUME [file tail $file] $port $posn"
@@ -211,7 +212,7 @@ proc killDel {arr usr file} {
     if ![info exists gs($usr)] return
     foreach p $gs($usr) {
 	switch -- [lindex $p 1] $file {
-	    catch {exec kill -9 [lindex $p 0]} msg
+	    catch {exec kill -9 [pid [lindex $p 0]]} msg
 	    listdel gs($usr) $i
 	    switch -- $gs($usr) {} {unset gs($usr) ; $usr deref}
 	    set conn [lindex $p 2]
